@@ -12,6 +12,7 @@
 #' calc_esses(estimates, sample_interval = 1000)
 #' @export
 #' @author Richèl J.C. Bilderbeek
+#' @encoding UTF-8
 calc_esses <- function(
   traces,
   sample_interval
@@ -40,8 +41,10 @@ calc_esses <- function(
 
   df <- traces[1, ]
   df[1, ] <- esses
-  testit::assert(nrow(df) == 1)
-  testit::assert(names(df) == names(traces))
+  stopifnot(
+    nrow(df) == 1,
+    names(df) == names(traces)
+  )
 
   # Round off values to nearest integers
   df[1, ] <- as.integer(as.numeric(df[1, ]) + 0.5)
