@@ -5,6 +5,7 @@
 #'   use \link{is_trees_file} with \code{verbose = TRUE}
 #'   for the reason
 #' @author Richèl J.C. Bilderbeek
+#' @encoding UTF-8
 #' @export
 count_trees_in_file <- function(
   trees_filename
@@ -22,9 +23,9 @@ count_trees_in_file <- function(
   }
   # pattern = "(^tree STATE_)|(\tTREE \\* UNTITLED = \\[&R\\] \\()")
   sum(
-    stringr::str_detect(
-      string = readLines(trees_filename, warn = FALSE),
-      pattern = "(^tree STATE_)|(\tTREE \\* (UNTITLED|STATE_[:digit:]*) = \\[&R\\] \\()"
+    grepl(
+      "(^tree STATE_)|(\tTREE \\* (UNTITLED|STATE_[0-9]*) = \\[&R\\] \\()",
+      readLines(trees_filename, warn = FALSE)
     )
   )
 }
