@@ -6,11 +6,12 @@
 #'   the unparsed BEAST2 MCMC operator acceptances
 #' @export
 #' @author Richèl J.C. Bilderbeek
+#' @encoding UTF-8
 extract_operators_lines <- function(filename) {
 
   if (!file.exists(filename)) {
     stop("'filename' must be the name of an existing file. ",
-      "File '", filename, "' not found")
+         "File '", filename, "' not found")
   }
 
   lines <- readLines(filename, warn = FALSE)
@@ -20,12 +21,12 @@ extract_operators_lines <- function(filename) {
     stop("Start of BEAST2 operators JSON not found")
   }
   start_index <- which(start_indices == TRUE)
-  testit::assert(lines[start_index] == "{\"operators\":[")
+  stopifnot(lines[start_index] == "{\"operators\":[")
 
   end_indices <- lines ==  "]}"
-  testit::assert(sum(end_indices) == 1)
+  stopifnot(sum(end_indices) == 1)
   end_index <- which(end_indices == TRUE)
-  testit::assert(lines[end_index] == "]}")
+  stopifnot(lines[end_index] == "]}")
 
   operator_lines <- lines[start_index:end_index]
   operator_lines
